Skip to content
Open
Show file tree
Hide file tree
Changes from all commits
Commits
Show all changes
29 commits
Select commit Hold shift + click to select a range
a01e8c8
start merging with current QUDA develop
pittlerf Oct 5, 2022
f31adba
small progress in the compilation of current develop QUDA
pittlerf Oct 10, 2022
543f385
include target cuda
pittlerf Oct 10, 2022
7bf7678
added codes and kernels for Soft Function and TMDPDFs with one-end an…
Oct 13, 2022
3084a48
Delete .#WallSourceNucleon.shexit
sbacchio Oct 13, 2022
d6bb238
Delete .#slurm-243497.out
sbacchio Oct 13, 2022
368f609
replacing checkCudaError with checkQudaError
pittlerf Oct 18, 2022
a630d62
remove artificial files
pittlerf Oct 18, 2022
49b9212
Merge branch 'master' of github.com:cylqcd/PLEGMA into softfunctionTM…
sbacchio Oct 19, 2022
643b1c0
Correcting time_step
sbacchio Oct 19, 2022
e2d4fc3
defining QUDA_PRECISION
pittlerf Oct 25, 2022
6f0a8c8
including checkQudaError in PLEGMA_BLAS.h
pittlerf Oct 25, 2022
b439586
including get_stream for creating process id
pittlerf Oct 25, 2022
b5f46e5
adding the location of get_stream
pittlerf Oct 25, 2022
c2560b9
updating QUDA_interface.cpp
pittlerf Oct 25, 2022
eb7fb72
removing non-longer existed parameters in inv_param
pittlerf Oct 25, 2022
6772da0
using device::get_stream instead of target::cuda::get_stream
pittlerf Oct 25, 2022
6d9382e
restoring compilation
pittlerf Oct 25, 2022
e93e1e8
restoring compilation
pittlerf Oct 25, 2022
4e186f5
renaming clover to clover_term
pittlerf Oct 25, 2022
92bc63b
correcting typo in documentation
pittlerf Oct 26, 2022
cbf4412
getting compiled
pittlerf Oct 27, 2022
61463d8
replacing functions needed default topology
pittlerf Nov 2, 2022
64e1600
replacing functions needed default topology 2
pittlerf Nov 2, 2022
0a24cca
merging PLEGMA_Field.cu
pittlerf Nov 6, 2022
bf16b3d
replacing checkCudaError with checkQudaError
pittlerf Nov 6, 2022
a55e8c8
Merge remote-tracking branch 'origin/heavy_light_tetraquark' into HEAD
pittlerf Nov 7, 2022
1bfcd10
correcting time_step for tetraquarks kernel
pittlerf Nov 7, 2022
6a7d09b
Merge branch 'master' into merge_quda_develop
sbacchio Nov 25, 2022
File filter

Filter by extension

Filter by extension

Conversations
Failed to load comments.
Loading
Jump to
Jump to file
Failed to load files.
Loading
Diff view
Diff view
30 changes: 19 additions & 11 deletions CMakeLists.txt
Original file line number Diff line number Diff line change
Expand Up @@ -5,7 +5,7 @@ set(CMAKE_INCLUDE_DIRECTORIES_PROJECT_BEFORE ON)
set(CMAKE_COLOR_MAKEFILE ON)
set(CMAKE_CUDA_SEPARABLE_COMPILATION ON)
set(CMAKE_CXX_STANDARD_REQUIRED True)
set(CMAKE_CXX_STANDARD 14)
set(CMAKE_CXX_STANDARD 17)
include(CheckIncludeFileCXX)
include(CheckSymbolExists)

Expand Down Expand Up @@ -33,6 +33,16 @@ endif()
FIND_LIBRARY(QUDA_LIB quda ${QUDA_HOME}/lib)
include_directories(SYSTEM ${QUDA_HOME}/include)

set(QUDA_PRECISION
"14"
CACHE STRING "which precisions to instantiate in QUDA (4-bit number - double, single, half, quarter)")
set(QUDA_RECONSTRUCT
"7"
CACHE STRING "which reconstructs to instantiate in QUDA (3-bit number - 18, 13/12, 9/8)")
add_definitions(-DQUDA_PRECISION=${QUDA_PRECISION})
add_definitions(-DQUDA_RECONSTRUCT=${QUDA_RECONSTRUCT})


set(QUDA_SRC "" CACHE PATH "path to QUDA src directory")
if("${QUDA_SRC}" STREQUAL "")
message( FATAL_ERROR "QUDA_SRC must be defined" )
Expand Down Expand Up @@ -149,7 +159,6 @@ set(PLEGMA_LIGHT_BARYONS FALSE CACHE BOOL "compile contractions for all light ba
if(PLEGMA_LIGHT_BARYONS)
add_definitions(-DPLEGMA_LIGHT_BARYONS)
endif()

set(PLEGMA_SCATTERING_CONTRACTIONS FALSE CACHE BOOL "compile contractions for pi-N scattering")
if (PLEGMA_SCATTERING_CONTRACTIONS)
add_definitions(-DPLEGMA_SCATTERING_CONTRACTIONS)
Expand Down Expand Up @@ -264,7 +273,7 @@ find_package(PythonInterp)
if(${CMAKE_VERSION} VERSION_GREATER 3.7.99)
find_package(CUDAWrapper)
set(USING_CUDA_LANG_SUPPORT True)
set(CMAKE_CUDA_STANDARD 14)
set(CMAKE_CUDA_STANDARD 17)
set(CMAKE_CUDA_STANDARD_REQUIRED True)
else()
set(CUDA_HOST_COMPILER "${CMAKE_CXX_COMPILER}" CACHE FILEPATH "Host side compiler used by NVCC")
Expand Down Expand Up @@ -415,7 +424,7 @@ add_definitions(-D__COMPUTE_CAPABILITY__=${COMP_CAP})

# NVCC FLAGS independet off build type
if(NOT USING_CUDA_LANG_SUPPORT)
set(CUDA_NVCC_FLAGS "-std c++11 -arch=${GPU_ARCH} -ftz=true -prec-div=false -prec-sqrt=false")
set(CUDA_NVCC_FLAGS "-std c++17 -arch=${GPU_ARCH} -ftz=true -prec-div=false -prec-sqrt=false")
else()
set(CUDA_NVCC_FLAGS "-ftz=true -prec-div=false -prec-sqrt=false")
set(CMAKE_CUDA_FLAGS "-arch=${GPU_ARCH}" CACHE STRING "Flags used by the CUDA compiler" FORCE)
Expand Down Expand Up @@ -471,17 +480,17 @@ set(CMAKE_CUDA_FLAGS_DEBUG "${CUDA_NVCC_FLAGS} -g -DHOST_DEBUG -G" CACHE STRING
FORCE )

#define CXX FLAGS
set(CMAKE_CXX_FLAGS_DEVEL "${OpenMP_CXX_FLAGS} -O3 -Wall ${CLANG_FORCE_COLOR}" CACHE STRING
set(CMAKE_CXX_FLAGS_DEVEL "${OpenMP_CXX_FLAGS} -std=c++17 -O3 -Wall ${CLANG_FORCE_COLOR}" CACHE STRING
"Flags used by the C++ compiler during regular development builds.")
set(CMAKE_CXX_FLAGS_STRICT "${OpenMP_CXX_FLAGS} -O3 -Wall -Werror ${CLANG_NOERROR}" CACHE STRING
set(CMAKE_CXX_FLAGS_STRICT "${OpenMP_CXX_FLAGS} -std=c++17 -O3 -Wall -Werror ${CLANG_NOERROR}" CACHE STRING
"Flags used by the C++ compiler during strict jenkins builds.")
set(CMAKE_CXX_FLAGS_RELEASE "${OpenMP_CXX_FLAGS} -O3 -w" CACHE STRING
set(CMAKE_CXX_FLAGS_RELEASE "${OpenMP_CXX_FLAGS} -std=c++17 -O3 -w" CACHE STRING
"Flags used by the C++ compiler during release builds.")
set(CMAKE_CXX_FLAGS_HOSTDEBUG "${OpenMP_CXX_FLAGS} -Wall -Wno-unknown-pragmas -g -fno-inline -DHOST_DEBUG ${CLANG_FORCE_COLOR}" CACHE STRING
set(CMAKE_CXX_FLAGS_HOSTDEBUG "${OpenMP_CXX_FLAGS} -std=c++17 -Wall -Wno-unknown-pragmas -g -fno-inline -DHOST_DEBUG ${CLANG_FORCE_COLOR}" CACHE STRING
"Flags used by the C++ compiler during host-debug builds.")
set(CMAKE_CXX_FLAGS_DEVICEDEBUG "${OpenMP_CXX_FLAGS} -Wall -Wno-unknown-pragmas ${CLANG_FORCE_COLOR}" CACHE STRING
set(CMAKE_CXX_FLAGS_DEVICEDEBUG "${OpenMP_CXX_FLAGS} -std=c++17 -Wall -Wno-unknown-pragmas ${CLANG_FORCE_COLOR}" CACHE STRING
"Flags used by the C++ compiler during device-debug builds.")
set(CMAKE_CXX_FLAGS_DEBUG "${OpenMP_CXX_FLAGS} -Wall -Wno-unknown-pragmas -g -fno-inline -DHOST_DEBUG ${CLANG_FORCE_COLOR}" CACHE STRING
set(CMAKE_CXX_FLAGS_DEBUG "${OpenMP_CXX_FLAGS} -std=c++17 -Wall -Wno-unknown-pragmas -g -fno-inline -DHOST_DEBUG ${CLANG_FORCE_COLOR}" CACHE STRING

Copy link
Copy Markdown
Contributor

Choose a reason for hiding this comment

The reason will be displayed to describe this comment to others. Learn more.

isn't enough the change in CUDA_NVCC_FLAGS?

"Flags used by the C++ compiler during full (host+device) debug builds.")

OPTION(USE_OpenMP "Use OpenMP" ON)
Expand Down Expand Up @@ -555,4 +564,3 @@ add_subdirectory(tests)
### add PLEGMA directory
add_subdirectory(utils)
add_subdirectory(plegma)

5 changes: 3 additions & 2 deletions include/PLEGMA_BLAS.h
Original file line number Diff line number Diff line change
Expand Up @@ -13,6 +13,7 @@

#include <cublas_v2.h>
#include <mpi.h>
#include <PLEGMA_utils.h>
#pragma once
enum OPER_MATR_BLAS {NOTRANS, TRANS, DAGGER};
namespace cBLAS{
Expand Down Expand Up @@ -233,7 +234,7 @@ namespace cuBLAS{
if(comm == MPI_COMM_NULL) PLEGMA_error("Communicator is NULL and cannot be used for MPI reduction");
cuBLAS::gemv_(trans, m, n, alpha, A, x, beta, y);
cudaMemcpy(yHost,y,n*2*sizeof(Float),cudaMemcpyDeviceToHost);
checkCudaError();
checkQudaError();
int mpiErr = MPI_Allreduce(MPI_IN_PLACE,yHost,n*2,MPI_Type(yHost),MPI_SUM,comm);
if(mpiErr != MPI_SUCCESS) PLEGMA_error("MPI_Allreduce failed with error %d\n", mpiErr);
}
Expand All @@ -245,7 +246,7 @@ namespace cuBLAS{
Float yHost[n*2];
cuBLAS::gemv(trans,m, n, alpha, A, x, beta, y, yHost,comm);
cudaMemcpy(y,yHost,sizeof(yHost),cudaMemcpyHostToDevice);
checkCudaError();
checkQudaError();
}
}
//=================================================================//
Expand Down
25 changes: 24 additions & 1 deletion include/PLEGMA_Correlator.h
Original file line number Diff line number Diff line change
Expand Up @@ -204,9 +204,13 @@ namespace plegma {
void contractMesonsAll(PLEGMA_Propagator<Float> &prop1,
PLEGMA_Propagator<Float> &prop2);


void contractBaryons(PLEGMA_Propagator<Float> &prop1,
PLEGMA_Propagator<Float> &prop2);

void contractBaryonsWall(PLEGMA_Propagator<Float> &prop1,
PLEGMA_Propagator<Float> &prop2,
PLEGMA_Propagator<Float> &prop3,
PLEGMA_Propagator<Float> &prop4);

void contractBaryonsUDSC(PLEGMA_Propagator<Float> &propUP,
PLEGMA_Propagator<Float> &propDN,
Expand Down Expand Up @@ -319,12 +323,31 @@ namespace plegma {
int signProps, std::vector<GAMMAS> gammas,
int z, std::string quark);

void contractNucleonThrp_staple(PLEGMA_Propagator<Float> &bwdProp,
PLEGMA_Propagator<Float> &fwdProp,
PLEGMA_Su3field<Float> &su3,
int signProps, std::vector<GAMMAS> gammas, bool isZfac, int b, int l, int z);

void contractNucleonThrp_qgq(PLEGMA_Propagator<Float> &bwdProp,
PLEGMA_Propagator<Float> &fwdProp,
PLEGMA_Su3field<Float> &su3_1,
PLEGMA_Fmunu<Float> &Fmunu, std::pair<int,int> munu,
PLEGMA_Su3field<Float> &su3_2,
int signProps, std::vector<GAMMAS> gammas, int z2, int z1);
void contractMesonsFourp_ultralocal_oneendtrick(PLEGMA_Propagator<Float> &prop1,
PLEGMA_Propagator<Float> &prop2,int b);

void contractMesonsFourp_ultralocal(PLEGMA_Propagator<Float> &prop1,
PLEGMA_Propagator<Float> &prop2,
PLEGMA_Propagator<Float> &prop3,
PLEGMA_Propagator<Float> &prop4,int b);

void contractTMDWFMesonsTrick_Zfac(PLEGMA_Propagator<Float> &prop1,
PLEGMA_Su3field<float> &staple, int b, int l);

void contractTMDWFMesons_Zfac(PLEGMA_Propagator<Float> &prop1,
PLEGMA_Propagator<Float> &prop2,
PLEGMA_Su3field<float> &staple, int b, int l);

virtual void writeASCII(std::string filename) const;
virtual void writeHDF5(std::string filename) const;
Expand Down
3 changes: 3 additions & 0 deletions include/PLEGMA_Field.h
Original file line number Diff line number Diff line change
Expand Up @@ -341,6 +341,9 @@ namespace plegma {
* @param munu: the mu,nu pair of lorentz indices of the Plq
*/
void trPmunu(PLEGMA_Gauge<Float> &gauge, std::pair<int,int> munu);

void SU3Trace(PLEGMA_Su3field<Float> &su3field);

/**
@brief Absorbs all elements from a 3D field and puts it at a specific global time of the 4D field
@param PLEGMA_Field3D<Float> prop, The 3D field
Expand Down
8 changes: 5 additions & 3 deletions include/PLEGMA_Hprobing.h
Original file line number Diff line number Diff line change
@@ -1,4 +1,6 @@
#pragma once
//#include <PLEGMA_utils.h>
#include <tune_quda.h>

namespace plegma {
inline int getVecToInd(std::vector<int> x, std::vector<int> L){
Expand Down Expand Up @@ -100,15 +102,15 @@ namespace plegma {
createColLattice();
// if(check)checkColoring();
cudaMalloc((void**)&d_arrVc, HGC_localVolume*sizeof(int));
checkCudaError();
// checkQudaError();
cudaMemcpy(d_arrVc, h_arrVc, HGC_localVolume*sizeof(int), cudaMemcpyHostToDevice);
checkCudaError();
// checkQudaError();
}
~PLEGMA_Hprobing(){
delete[] h_arrVc;
delete[] arrlc;
cudaFree(d_arrVc);
checkCudaError();
//checkQudaError();
}
int* H_arrVc() const{return h_arrVc;}
int* D_arrVc() const{return d_arrVc;}
Expand Down
1 change: 1 addition & 0 deletions include/PLEGMA_Propagator.h
Original file line number Diff line number Diff line change
Expand Up @@ -57,6 +57,7 @@ namespace plegma {
void applyBoundaries_device(int t0);
void rotateToPhysicalBase_host(int sign);
void rotateToPhysicalBase_device(int sign);
void PropmulVVdag(PLEGMA_Vector<Float> &vec1,PLEGMA_Vector<Float> &vec2);
};

///////////////////////////////
Expand Down
2 changes: 1 addition & 1 deletion include/PLEGMA_ScattCorrelator.h
Original file line number Diff line number Diff line change
Expand Up @@ -190,7 +190,7 @@ namespace plegma {
void T1( std::vector<GAMMAS_SCATT> &Gammas_i, std::vector<GAMMAS_SCATT> &Gammas_f, PLEGMA_Propagator<Float> &S1, PLEGMA_Propagator<Float> &S2, PLEGMA_Propagator<Float> &S3 );
/**
* @brief performs T2 type reduction to compute baryon 2pt functions
* T2_{alpha,beta}=\epsilon_{a,b,c}\epsilon_{l,m,n}S2^{c,l}_{alpha,beta}\Gamma_{i}_{alpha0,alpha1}S2^{b,m}_{beta0,alpha1}\Gamma_{f}_{beta0,beta1}S3^{a,n}_{beta1,alpha0}
* T2_{alpha,beta}=\epsilon_{a,b,c}\epsilon_{l,m,n}S1^{c,l}_{alpha,beta}\Gamma_{i}_{alpha0,alpha1}S2^{b,m}_{beta0,alpha1}\Gamma_{f}_{beta0,beta1}S3^{a,n}_{beta1,alpha0}
* @param std::vector<GAMMAS_SCATT> &Gammas_i: list of gammas at the source for the contractions
* @param std::vector<GAMMAS_SCATT> &Gammas_f: list of gammas at the sink for the contractions
* @param PLEGMA_Propagator<Float> &S1: propagator to the sink spin from the source spin index
Expand Down
3 changes: 3 additions & 0 deletions include/PLEGMA_global.h
Original file line number Diff line number Diff line change
Expand Up @@ -43,6 +43,9 @@ using namespace std::chrono_literals;

//======== Preprocessor macros =========//
#include <global/PLEGMA_macros.hpp>
#include <tune_quda.h>
#include <comm_quda.h>
using namespace quda;

namespace plegma {
//======== PLEGMA_printf, PLEGMA_error, PLEGMA_warning =========//
Expand Down
1 change: 1 addition & 0 deletions include/PLEGMA_utils.h
Original file line number Diff line number Diff line change
Expand Up @@ -33,6 +33,7 @@ void setInvertParam(QudaInvertParam &inv_param);
void setEigMultigridParam(QudaMultigridParam &mg_param, QudaEigParam *mg_eig_param);
#endif
//============== PLEGMA_utils.cpp =======================================//
void checkQudaError();
void createMom(int *Nmom, int momElem[][3], int Q_qs);
extern const std::vector<std::string> listAvailOptPLEGMA;
void initializeOptions(int argc, char **argv, bool withQuda=true, std::vector<std::string> listOptPLEGMA = listAvailOptPLEGMA);
Expand Down
1 change: 1 addition & 0 deletions include/global/PLEGMA_Options.h
Original file line number Diff line number Diff line change
@@ -1,5 +1,6 @@
#pragma once
#include "PLEGMA_templates.h"
#include <comm_quda.h>
struct argument{std::string name, value;};

class Arguments{
Expand Down
3 changes: 1 addition & 2 deletions include/global/PLEGMA_prints.hpp
Original file line number Diff line number Diff line change
Expand Up @@ -8,7 +8,6 @@ extern bool HGC_hold_exit; // used to hold exit until all the errors have been p
extern bool HGC_init_PLEGMA_flag;
extern struct global_vars HGC_global_vars;
extern class Options * HGC_options;

#define PLEGMA_exit(value) do { \
if(! HGC_hold_exit) { \
if (HGC_init_PLEGMA_flag) { \
Expand Down Expand Up @@ -53,7 +52,7 @@ extern class Options * HGC_options;
fprintf(getOutputFile(), "%sERROR: ", getOutputPrefix()); \
fprintf(getOutputFile(), __VA_ARGS__); \
fprintf(getOutputFile(), " (rank %d, host %s, " __FILE__ ":%d in %s())\n", \
comm_rank(), comm_hostname(), __LINE__, __func__); \
comm_rank(), comm_hostname(), __LINE__, __func__); \
fprintf(getOutputFile(), "%s last kernel called was (name=%s,volume=%s,aux=%s)\n", \
getOutputPrefix(), getLastTuneKey().name, \
getLastTuneKey().volume, getLastTuneKey().aux); \
Expand Down
12 changes: 8 additions & 4 deletions include/global/PLEGMA_structs.h
Original file line number Diff line number Diff line change
Expand Up @@ -63,14 +63,18 @@ struct pointer_holder {

void copyToDeviceConstant() {
if(devPointer != nullptr) {
cudaMemcpyToSymbol( *devPointer, hostPointer, bytes*size);
checkCudaError();
cudaError_t err = cudaMemcpyToSymbol( *devPointer, hostPointer, bytes*size);
if (err != cudaSuccess) {
errorQuda("Failed to copy constant host memory of size to device %zu \n", size);
}
}
}
void copyFromDeviceConstant() {
if(false and devPointer != nullptr) {
cudaMemcpyFromSymbol(hostPointer, *devPointer, bytes*size, 0, cudaMemcpyDeviceToHost);
checkCudaError();
cudaError_t err = cudaMemcpyFromSymbol(hostPointer, *devPointer, bytes*size, 0, cudaMemcpyDeviceToHost);
if (err != cudaSuccess) {
errorQuda("Failed to copy constant host memory of size to device %zu \n", size);
}
}
}
bool checkDeviceConstant() {
Expand Down
12 changes: 8 additions & 4 deletions include/global/PLEGMA_templates.h
Original file line number Diff line number Diff line change
Expand Up @@ -46,14 +46,18 @@ template<typename T> inline void hostFree(T &ptr) {

// Pinned memory allocation
template<typename T> inline void hostMallocPinned(T &ptr, size_t size){
cudaMallocHost((void**)&ptr, size);
checkCudaError();
cudaError_t err = cudaMallocHost((void**)&ptr, size);
if (err != cudaSuccess) {
errorQuda("Failed to allocate host memory of size %zu \n", size);
}
HGC_used_memory += size;
}

template<typename T> inline void hostFreePinned(T &ptr, size_t size) {
cudaFreeHost(ptr);
checkCudaError();
cudaError_t err = cudaFreeHost(ptr);
if (err != cudaSuccess) {
errorQuda("Failed to free host memory of size %zu \n", size);
}
ptr=NULL;
HGC_used_memory -= size;
}
Expand Down
2 changes: 1 addition & 1 deletion include/io/PLEGMA_lime.h
Original file line number Diff line number Diff line change
Expand Up @@ -2,7 +2,7 @@
extern "C" {
#include <lime.h>
}

#include <tune_quda.h>
#include <PLEGMA_global.h>
#include <unistd.h>
#include <stdio.h>
Expand Down
8 changes: 4 additions & 4 deletions include/utils/QUDA_interface.h
Original file line number Diff line number Diff line change
Expand Up @@ -17,7 +17,7 @@ namespace quda {
QudaMultigridParam mg_param;
Dirac *D, *DSloppy, *DPre;
DiracMatrix *M, *MSloppy, *MPre;
cudaColorSpinorField *b, *x;
ColorSpinorField *b, *x;
#ifdef QUDA_INCLUDES_COMMIT_775a033
QudaEigParam *mg_eig_param;
#endif
Expand All @@ -28,9 +28,9 @@ namespace quda {
void UpdateSolver();
QUDA_solver(double mu);
virtual ~QUDA_solver();
cudaColorSpinorField* solve(cudaColorSpinorField * rhs);
ColorSpinorField* solve(ColorSpinorField * rhs);
template<typename Float>
cudaColorSpinorField* solve(PLEGMA_Vector<Float> &vectorIn);
ColorSpinorField* solve(PLEGMA_Vector<Float> &vectorIn);
template<typename Float>
void solve(PLEGMA_Vector<Float> &out, PLEGMA_Vector<Float> &in);
template<typename Float>
Expand All @@ -43,7 +43,7 @@ namespace quda {
DiracParam dParam;
QudaInvertParam inv_param;
Dirac *D;
cudaColorSpinorField *in, *out;
ColorSpinorField *in, *out;
template<APP_TYPE type> void apply();
public:
//only QUDA_WILSON_DSLASH, QUDA_CLOVER_WILSON_DSLASH, QUDA_TWISTED_MASS_DSLASH, QUDA_TWISTED_CLOVER_DSLASH
Expand Down
24 changes: 12 additions & 12 deletions include/utils/QUDA_types.h
Original file line number Diff line number Diff line change
Expand Up @@ -284,8 +284,8 @@ inline QudaSchwarzType get_schwarz_type(std::string s) {
inline QudaTwistFlavorType get_flavor_type(std::string s) {
if(s=="singlet")
return QUDA_TWIST_SINGLET;
else if(s=="deg-doublet")
return QUDA_TWIST_DEG_DOUBLET;
// else if(s=="deg-doublet")
// return QUDA_TWIST_DEG_DOUBLET;
else if(s=="nondeg-doublet")
return QUDA_TWIST_NONDEG_DOUBLET;
else if(s=="no")
Expand All @@ -300,8 +300,8 @@ inline std::string get_flavor_str(QudaTwistFlavorType type) {
switch(type) {
case QUDA_TWIST_SINGLET:
return "singlet";
case QUDA_TWIST_DEG_DOUBLET:
return "deg-doublet";
// case QUDA_TWIST_DEG_DOUBLET:
// return "deg-doublet";
case QUDA_TWIST_NONDEG_DOUBLET:
return "nondeg-doublet";
case QUDA_TWIST_NO:
Expand All @@ -321,10 +321,10 @@ inline QudaInverterType get_solver_type(std::string s) {
return QUDA_GCR_INVERTER;
else if(s=="pcg")
return QUDA_PCG_INVERTER;
else if(s=="mpcg")
return QUDA_MPCG_INVERTER;
else if(s=="mpbicgstab")
return QUDA_MPBICGSTAB_INVERTER;
// else if(s=="mpcg")
// return QUDA_MPCG_INVERTER;
// else if(s=="mpbicgstab")
// return QUDA_MPBICGSTAB_INVERTER;
else if(s=="mr")
return QUDA_MR_INVERTER;
else if(s=="sd")
Expand Down Expand Up @@ -377,10 +377,10 @@ inline std::string get_solver_str(QudaInverterType type) {
return "gcr";
case QUDA_PCG_INVERTER:
return "pcg";
case QUDA_MPCG_INVERTER:
return "mpcg";
case QUDA_MPBICGSTAB_INVERTER:
return "mpbicgstab";
// case QUDA_MPCG_INVERTER:
// return "mpcg";
// case QUDA_MPBICGSTAB_INVERTER:
// return "mpbicgstab";
case QUDA_MR_INVERTER:
return "mr";
case QUDA_SD_INVERTER:
Expand Down
1 change: 1 addition & 0 deletions lib/CMakeLists.txt
Original file line number Diff line number Diff line change
Expand Up @@ -18,6 +18,7 @@ set (PLEGMA_OBJS
kernels/PLEGMA_threep_threeD_part3.cu
kernels/PLEGMA_threep_threeD_part4.cu
kernels/PLEGMA_threep_wilsonLine.cu
kernels/PLEGMA_threep_staple.cu
kernels/PLEGMA_threep_qgq.cu
PLEGMA_QLoops.cu
PLEGMA_FT.cu
Expand Down
Loading